
/**************************************************************************
** 
** File name   : replication_robustness.do
** Date        : May 7th, 2012
** Author      : Christina J. Schneider (cjschneider@ucsd.edu)
** Paper	   : Domestic Elections, Political Competence, and Distributional 
					Bargaining in the European Union
** Purpose     : Replicate Tables 3, 5, 6, and 7
** Requires    : replication.dta, replication_main.do, replication_robustness.do,
					replication_interactions.do, replications_appendices.do
** Output      : replication.log, figure2a.eps, figure3a.eps, figure4a.eps, 
					figure5a.eps, figure6a.eps, figure7a.eps, figure2b.eps, 
					figure3b.eps, figure4b.eps, figure5b.eps, figure6b.eps, 
					figure7b.eps
**
**************************************************************************/ 


#delimit ;

**TABLE 3, MODEL 1**;

logit election_year ctot_pct minority id_*, robust;
predict res_en, resid;
label variable res_en "Residuals";
xtpcse ctot_pct preelection election_year employagri_ln gdppercap_eu100 unemployment sscouncil_pct 
	eusupport newmember size res_en  id_*, correlation(psar1);


********************


**TABLE 5, MODEL 1**;

xtpcse ctot_pct preelec_franz election_year employagri_ln gdppercap_eu100  unemployment sscouncil_pct eusupport  
	newmember size  id_*, correlation(psar1);

**TABLE 5, MODEL 2**;

xtpcse ctot_pct preelection_exe electionyear_exe employagri_ln gdppercap_eu100   unemployment sscouncil_pct eusupport  
	newmember size  id_*, correlation(psar1);

**TABLE 5, MODEL 3**;

xtpcse ctot_pct yrstoelection employagri_ln gdppercap_eu100   unemployment sscouncil_pct eusupport 
	newmember size  id_*, correlation(psar1);

**TABLE 5, MODEL 4**;

xtpcse ctot_pct postelection election_year employagri_ln gdppercap_eu100  unemployment sscouncil_pct eusupport 
	 newmember size  id_*, correlation(psar1);

**TABLE 5, MODEL 5**;

xtpcse ctot_pct preelection_rr election_year employagri_ln gdppercap_eu100   unemployment sscouncil_pct eusupport  
	newmember size  id_*, correlation(psar1);

*********************


**TABLE 6, MODEL 1**;

xtpcse ctot_pct preelection election_year employagri_ln gdppercap_eu100   unemployment sscouncil_pct eusupport newmember size 
	ffnegotiation id_*, correlation(psar1);

**TABLE 6, MODEL 2**;

xtpcse ctotnet_ln preelection election_year employagri_ln gdppercap_eu100   unemployment sscouncil_pct eusupport  
	newmember size id_*, correlation(psar1);

**TABLE 6, MODEL 3**;

xtpcse ctot_pct preelection election_year partisan_diff prepartisandiff employagri_ln gdppercap_eu100   unemployment sscouncil_pct eusupport 
	newmember size  id_*, correlation(psar1) pairwise;

**********************


**TABLE 7, MODEL 1**;

xtpcse ctot_pct ctot_pct_lag preelection election_year employagri_ln gdppercap_eu100   unemployment sscouncil_pct eusupport 
	 newmember size  id_*;

**TABLE 7, MODEL 2**;

xtpcse ccap_pct ccap_pct_lag preelection election_year employagri_ln gdppercap_eu100   unemployment sscouncil_pct eusupport 
	 newmember size  id_*;

**TABLE 7, MODEL 3**;

xtpcse ctot_pct ctot_pct_lag ctot_pct_lag2 preelection election_year employagri_ln gdppercap_eu100   unemployment sscouncil_pct 
	eusupport newmember size  id_*;

**TABLE 7, MODEL 4**;

xtabond2 ctot_pct ctot_pct_lag ctot_pct_lag2 preelection election_year employagri_ln gdppercap_eu100  unemployment sscouncil_pct eusupport  
	newmember size id_*, iv(ctot_pct_lag ctot_pct_lag2 preelection election_year employagri_ln gdppercap_eu100  unemployment 
		sscouncil_pct eusupport newmember size id_*)  h(1) nomata;

exit;
